#!/usr/bin/Rscript

source("../lib/curve.r")
source("../lib/stats.r")
source("../lib/util.r")
source("../lib/eia.r")

# Main variables:
# pop - population
# tec - total energy consumption
# tco2 - total carbon dioxide emission
pop <- read.eia("../data/Population.csv")
lp <- setNames(pop$X2010, rownames(pop))
tec <- read.eia("../data/Total Energy Use.csv")
tco2 <- read.eia("../data/Total Carbon Dioxide Emissions.csv")

years <- as.numeric(substring(Filter(function (x) substr(x, 1, 1) == "X",
				     names(pop)), 2))

g <- c()
for (n in names(tec)) {
	year <- as.numeric(substring(n, 2))
	ytec <- setNames(tec[,n], rownames(n))
	ypop <- pop[,n]
	not.na <- !is.na(ytec) & !is.na(ypop)
	ytec <- ytec[not.na]
	ypop <- ypop[not.na]
	l <- Lorenz(ytec / ypop, ypop)
	g <- c(g, Gini(l))
}

# Write csv file for plot data
data <- data.frame(years, g, row.names=1)
colnames(data) <- c("Gini Coefficient of Global Energy Consumption")
write.csv(data, "Figure 5a.csv")

# Begin plotting
#################

pdf("Figure 5a.pdf", width=7, height=7)
par(mar=c(4.5, 4.5, 2.5, 0)+0.1)
plot(years, g,
     main="Gini Coefficient of Global Energy Consumption",
     xaxt="n", yaxt="n", pch=20,
     xlab="Year", ylab="Gini Coefficient", cex.main=1.5, cex.lab=1.6, cex=1.2, font.main=1,
     ylim=c(0.45, 0.7), xlim=c(1980, 2020))
axis(1, at=seq(1980, 2020, 1), labels=F)
axis(1, at=seq(1980, 2020, 5), tck=0.01)
axis(2, at=seq(0.45, 0.7, 0.01), labels=F)
axis(2, at=seq(0.45, 0.7, 0.05), tck=0.01)
clip(1995, 2020, 0.45, 0.7)
abline(line(tail(years, 11), tail(g, 11)), lty=2, col="blue", lwd=1.5)
do.call("clip", as.list(par("usr")))
curve(0.15 / (1 + exp((x - 2006.5)/5)) + 0.5, add=T, lty=6, col="red", lwd=1.5)
abline(0.5, 0, lty=1)
legend("topright",
       legend=c("Gini coefficient data",
		"Linear fit 2000-2010",
		"Sigmoid fit",
		"Exponential distribution"),
       lty=c(0, 2, 6, 1), lwd=c(1, 1.5, 1.5, 1), pch=c(20, NA, NA, NA),
       col=c("black", "blue", "red", "black"),
       cex=1.3)

text(1979, 0.45, "Data source: EIA", pos=4, cex=1.6, font=1)

g <- c()
for (n in names(tco2)) {
	year <- as.numeric(substring(n, 2))
	ytco2 <- setNames(tco2[,n], rownames(n))
	ypop <- pop[,n]
	not.na <- !is.na(ytco2) & !is.na(ypop)
	ytco2 <- ytco2[not.na]
	ypop <- ypop[not.na]
	l <- Lorenz(ytco2 / ypop, ypop)
	g <- c(g, Gini(l))
}
