Lorenz <- function (d, w = rep(1, length(d))) {
	# Lorenz curve
	#
	# Args:
	#   d: The data
	#   w: (Optional) Weights of the data
	# 
	# Returns:
	#   The lorenz curve

	nd <- d / sum(d)
	nw <- w / sum(w)
	o <- order(nd, na.last=NA)

	wsum <- cumsum(nd[o] * w[o])
	m <- rbind(cumsum(nw[o]), wsum / max(wsum))
	l <- split(m, col(m))
	class(l) <- c("lorenz", "curve")
	return(l)
}

Gini <- function (x) {
	# Compute the gini coefficient of a data set.
	#
	# Args:
	#   x: The data, or a lorenz curve from the data
	#
	# Returns:
	#   The gini coefficient
	UseMethod("Gini")
}

Gini.lorenz <- function (l)
	return(2 * (0.5 - integrate.curve(l)$value))

Gini.numeric <- function (v)
	return(Gini.lorenz(Lorenz(v)))
